@@ -21,7 +21,7 @@ __all__ = [
     # 环境变量-读写
     "set_os_environ", "unset_os_environ", "get_os_environment",
     # 全局常量
-    "BASE_DIR", "TESTCASE_DIR", "DATA_DIR", "LOG_DIR", "REPORT_DIR",  # 全局路径 dir
+    "CWD", "BASE_DIR", "LOG_DIR", "REPORT_DIR",  # 全局路径 dir
     "global_cf",
     "DB_INFO",  # 数据库配置
     "TIME_STR",  # 时间戳
